@@ -496,7 +496,7 @@ class _JavaObjectShadow:
         self._closed = False
         # In case there's an exception rather than normal garbage collection,
         # this makes sure cleanup occurs properly
-        atexit.register(self._close)
+        atexit.register(weakref.ref(self._close))
         self._close_lock = Lock()
 
     def _close(self):
@@ -865,7 +865,7 @@ _CLASS_NAME_MAPPING = {
 }
 #Used for deserializing java arrarys into numpy arrays
 _JAVA_ARRAY_TYPE_NUMPY_DTYPE = {
-    "boolean[]": np.bool,
+    "boolean[]": np.bool_,
     "byte[]": np.uint8,
     "short[]": np.int16,
     "char[]": np.uint16,
